hotspot/src/share/vm/memory/metaspaceShared.hpp
changeset 27404 33c0f343cd5c
parent 26408 d6defe172e25
child 27677 b1997f2f1b56
child 28018 abc067cd68fd
--- a/hotspot/src/share/vm/memory/metaspaceShared.hpp	Wed Oct 22 22:37:06 2014 +0000
+++ b/hotspot/src/share/vm/memory/metaspaceShared.hpp	Thu Oct 23 10:08:02 2014 -0700
@@ -57,11 +57,16 @@
   static bool _archive_loading_failed;
  public:
   enum {
-    vtbl_list_size = 17, // number of entries in the shared space vtable list.
-    num_virtuals = 200   // maximum number of virtual functions
-                         // If virtual functions are added to Metadata,
-                         // this number needs to be increased.  Also,
-                         // SharedMiscCodeSize will need to be increased.
+    vtbl_list_size         = 17,   // number of entries in the shared space vtable list.
+    num_virtuals           = 200,  // maximum number of virtual functions
+                                   // If virtual functions are added to Metadata,
+                                   // this number needs to be increased.  Also,
+                                   // SharedMiscCodeSize will need to be increased.
+                                   // The following 2 sizes were based on
+                                   // MetaspaceShared::generate_vtable_methods()
+    vtbl_method_size       = 16,   // conservative size of the mov1 and jmp instructions
+                                   // for the x64 platform
+    vtbl_common_code_size  = (1*K) // conservative size of the "common_code" for the x64 platform
   };
 
   enum {